/*
 * nars.h
 *
 * Copyright (C) 2010 Pavol Durisek
 *
 * This implementation of NARS (Non-Axiomatic Reasoning System) is based on
 * Non-Axiomatic Logic (NAL) Specification, Pei Wang, 2010, https://sites.google.com/site/narswang/
 *
 * Description: This header file represents an interface for a NARS dynamic library file (dll/so).
 *              The library is an implementation of Nal + control mechanism.
 */

#ifndef NARSI_H
#define NARSI_H

#include "stddef.h"

#if defined WIN32 && defined DLL
    #ifdef NARS_EXPORTS
        #define NARS_API __declspec(dllexport)
    #else
        #define NARS_API __declspec(dllimport)
    #endif
#elif defined  __GNUC__ >= 4 && defined DLL
        #define NARS_API __attribute__ ((visibility ("default")))
        //#define NARS_API_LOCAL __attribute__ ((visibility ("hidden")))
#else
    #define NARS_API // default - empty, for a standalone application
#endif

class Nars; 

extern "C" {
	// create Nars object
	NARS_API Nars* create_object(unsigned int numOfChannel, unsigned int numOfThreads); 

	// destroy nars object
	NARS_API void destroy_object(Nars* object); 

	// process NAL sentences
	NARS_API void process(Nars* object, const char* sentence, unsigned int lineNumber, unsigned int channel); 

	// get answer if available (or wait for it)
	NARS_API bool get(Nars* object, char* buffer, size_t& size, bool wait, int timeout, unsigned int channel); 
}

#endif
